@@ -133,7 +133,7 @@ class QLevelMeter(QWidget):
         qp.drawText(self.TEXT_LEFT_MARGIN, self.BAR_TOP_MARGIN, metrics.width("0dB") + 2, fontHeight, Qt.AlignLeft | Qt.AlignBaseline, "0dB")
         db -= 6
         # draW rest of label strings
-        top = self.BAR_TOP_MARGIN - fontHeight / 2
+        top = int(round(self.BAR_TOP_MARGIN - fontHeight / 2))
         while db >= self.MIN_DB:
             top += spacing
             s = str(db)
